Unofficial parser for aaltopoiju.fi
===================================

This is unofficial parser - screen scraper - for aaltopoju.fi website. Please check possible conditions and terms before using. This will probably break on every website update.

Installation
------------

::

  pip install aaltopoiju
